import 'package:equatable/equatable.dart';
import 'package:flutter/cupertino.dart';

abstract class ProfileEvent extends Equatable {
  const ProfileEvent();

  @override
  List<Object> get props => [];
}

class InitialProfileEvent extends ProfileEvent {}

class TimeZoneInitialEvent extends ProfileEvent {}

class ChangeNameEvent extends ProfileEvent {
  final bool? value;
  const ChangeNameEvent({ this.value});
}

class RegionInitialEvent extends ProfileEvent {}


class SaveNameEvent extends ProfileEvent {
  final BuildContext context;
  const SaveNameEvent({required this.context});
  @override
  List<Object> get props => [context];
}


class SelectImageEvent extends ProfileEvent {
  final  BuildContext context;
  final bool isSelected;
  const SelectImageEvent({required this.context,required this.isSelected});
  @override
  List<Object> get props => [context,isSelected];
}


class ToggleRepeatEvent extends ProfileEvent {}

class SelectTimeZoneEvent extends ProfileEvent {
  final String val;
  final BuildContext context;
  const SelectTimeZoneEvent({required this.val,required this.context});
  @override
  List<Object> get props => [val];
}

class SelectRegionEvent extends ProfileEvent {
  final String val;
  final BuildContext context;
  const SelectRegionEvent({required this.val,required this.context});
  @override
  List<Object> get props => [val,context];
}


class SearchRegionEvent extends ProfileEvent {
  final String query;

  const SearchRegionEvent({required this.query});
  @override
  List<Object> get props => [query];
}

class SearchTimeZoneEvent extends ProfileEvent {
  final String query;

  const SearchTimeZoneEvent({required this.query});
  @override
  List<Object> get props => [query];
}



